
use crate::stackframe::StackFrame;
use crate::jvm::Error;
use crate::jvm::JVMCallbackOperation;
use crate::jvm::JVM;
use std::collections::HashMap;

#[derive(Debug, Default)]
pub struct NativeRegistry {
    methods: HashMap<MethodPath, NativeMethodCallable>,
}

impl NativeRegistry {
    pub fn get(&self, class_name: &String, method_name: &String) -> Option<&NativeMethodCallable> {
        self.methods.get(&MethodPath(class_name.to_string(), method_name.to_string()))
    }

    pub fn register(&mut self, class_name: &str, method_name: &str, n: NativeMethodCallable) {
        self.methods.insert(MethodPath(class_name.to_string(), method_name.to_string()), n);
    }
}

pub type NativeMethodCallable=fn (&mut JVM) -> Result<JVMCallbackOperation, Error>;

#[derive(Debug)]
#[derive(Eq, Hash, PartialEq)]
pub struct MethodPath(String, String);
